@@ -4,8 +4,8 @@ from django.db.backends.base.base import timezone_constructor
 from django.db.backends.postgresql.operations import (
     DatabaseOperations as PostgresDatabaseOperations,
 )
+from django.db.backends.postgresql.psycopg_any import errors, is_psycopg3
 from django.db.utils import OperationalError
-from psycopg2 import errorcodes
 
 
 class DatabaseOperations(PostgresDatabaseOperations):
@@ -20,25 +20,21 @@ class DatabaseOperations(PostgresDatabaseOperations):
         'AutoField': (-9223372036854775808, 9223372036854775807),
         'BigAutoField': (-9223372036854775808, 9223372036854775807),
     }
+
+    if is_psycopg3:
+        from psycopg.types import numeric
+
+        integerfield_type_map = {
+            "SmallIntegerField": numeric.Int2,
+            "IntegerField": numeric.Int8,
+            "BigIntegerField": numeric.Int8,
+            "PositiveSmallIntegerField": numeric.Int2,
+            "PositiveIntegerField": numeric.Int8,
+            "PositiveBigIntegerField": numeric.Int8,
+        }
+
     explain_options = frozenset(['DISTSQL', 'OPT', 'TYPES', 'VEC', 'VERBOSE'])
 
-    def datetime_extract_sql(self, lookup_type, sql, params, tzname):
-        if self.connection.features.is_cockroachdb_22_1:
-            return super().datetime_extract_sql(lookup_type, sql, params, tzname)
-        # Override the changes from https://github.com/django/django/commit/b7f263551c64e3f80544892e314ed5b0b22cc7c8
-        # which aren't compatible with older versions of CockroachDB:
-        # https://github.com/cockroachdb/cockroach/issues/76960
-        sql, params = self._convert_sql_to_tz(sql, params, tzname)
-        return self.date_extract_sql(lookup_type, sql, params)
-
-    def time_extract_sql(self, lookup_type, sql, params):
-        if self.connection.features.is_cockroachdb_22_1:
-            return super().time_extract_sql(lookup_type, sql, params)
-        # Override the changes from https://github.com/django/django/commit/b7f263551c64e3f80544892e314ed5b0b22cc7c8
-        # which aren't compatible with older versions of CockroachDB:
-        # https://github.com/cockroachdb/cockroach/issues/76960
-        return self.date_extract_sql(lookup_type, sql, params)
-
     def deferrable_sql(self):
         # Deferrable constraints aren't supported:
         # https://github.com/cockroachdb/cockroach/issues/31632
@@ -46,7 +42,7 @@ class DatabaseOperations(PostgresDatabaseOperations):
 
     def adapt_datetimefield_value(self, value):
         """
-        Add a timezone to datetimes so that psycopg2 will cast it to
+        Add a timezone to datetimes so that psycopg will cast it to
         TIMESTAMPTZ (as cockroach expects) rather than TIMESTAMP.
         """
         # getattr() guards against F() objects which don't have tzinfo.
@@ -89,7 +85,7 @@ class DatabaseOperations(PostgresDatabaseOperations):
             try:
                 return super().execute_sql_flush(sql_list)
             except OperationalError as exc:
-                if (getattr(exc.__cause__, 'pgcode', '') != errorcodes.SERIALIZATION_FAILURE or
+                if (not isinstance(exc.__cause__, errors.SerializationFailure) or
                         retry >= num_retries):
                     raise
                 time.sleep(next_retry_delay)
