@@ -24,6 +24,15 @@ class DatabaseSchemaEditor(PostgresDatabaseSchemaEditor):
     # statement. This isn't supported by CockroachDB.
     sql_update_with_default = "UPDATE %(table)s SET %(column)s = %(default)s WHERE %(column)s IS NULL"
 
+    def __enter__(self):
+        super().__enter__()
+        # As long as DatabaseFeatures.can_rollback_ddl = False, compose() may
+        # fail if connection is None as per
+        # https://github.com/django/django/pull/15687#discussion_r1038175823.
+        # See also https://github.com/django/django/pull/15687#discussion_r1041503991.
+        self.connection.ensure_connection()
+        return self
+
     def add_index(self, model, index, concurrently=False):
         if index.contains_expressions and not self.connection.features.supports_expression_indexes:
             return None
@@ -75,8 +84,7 @@ class DatabaseSchemaEditor(PostgresDatabaseSchemaEditor):
                     }
                 })
 
-    def _alter_column_type_sql(self, model, old_field, new_field, new_type):
-        self.sql_alter_column_type = 'ALTER COLUMN %(column)s TYPE %(type)s'
+    def _alter_column_type_sql(self, model, old_field, new_field, new_type, old_collation, new_collation):
         new_internal_type = new_field.get_internal_type()
         old_internal_type = old_field.get_internal_type()
         # Make ALTER TYPE with AutoField make sense.
@@ -90,6 +98,7 @@ class DatabaseSchemaEditor(PostgresDatabaseSchemaEditor):
                     self.sql_alter_column_type % {
                         "column": self.quote_name(column),
                         "type": new_type,
+                        "collation": "",
                     },
                     [],
                 ),
@@ -99,7 +108,10 @@ class DatabaseSchemaEditor(PostgresDatabaseSchemaEditor):
                 [],
             )
         else:
-            return BaseDatabaseSchemaEditor._alter_column_type_sql(self, model, old_field, new_field, new_type)
+            return BaseDatabaseSchemaEditor._alter_column_type_sql(
+                self, model, old_field, new_field, new_type,
+                old_collation, new_collation,
+            )
 
     def _field_should_be_indexed(self, model, field):
         # Foreign keys are automatically indexed by cockroachdb.
