@@ -1,5 +1,4 @@
 from django.contrib.gis.db.backends.postgis.operations import PostGISOperations
-from django.utils.functional import cached_property
 
 from django_cockroachdb.operations import (
     DatabaseOperations as CockroachOperations,
@@ -29,14 +28,9 @@ class DatabaseOperations(CockroachOperations, PostGISOperations):
         del ops['strictly_below']  # <<|
         return ops
 
-    @cached_property
-    def unsupported_functions(self):
-        unsupported = {
-            'AsGML',  # st_asgml(): https://github.com/cockroachdb/cockroach/issues/48877
-            'AsKML',  # st_askml(geometry, int): https://github.com/cockroachdb/cockroach/issues/48881
-            'AsSVG',  # st_assvg(): # https://github.com/cockroachdb/cockroach/issues/48883
-            'GeometryDistance',  # <-> operator: https://github.com/cockroachdb/cockroach/issues/57099
-        }
-        if not self.connection.features.is_cockroachdb_21_1:
-            unsupported.update({'BoundingCircle', 'LineLocatePoint', 'MemSize'})
-        return unsupported
+    unsupported_functions = {
+        'AsGML',  # st_asgml(): https://github.com/cockroachdb/cockroach/issues/48877
+        'AsKML',  # st_askml(geometry, int): https://github.com/cockroachdb/cockroach/issues/48881
+        'AsSVG',  # st_assvg(): # https://github.com/cockroachdb/cockroach/issues/48883
+        'GeometryDistance',  # <-> operator: https://github.com/cockroachdb/cockroach/issues/57099
+    }
